package de.mlessmann.certassist.models;

import jakarta.persistence.*;
import java.time.ZonedDateTime;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.CreationTimestamp;
import org.hibernate.annotations.UpdateTimestamp;

/**
 * Database entity representing a passphrase.
 * Unlike passwords which would be stored using BCrypt, passphrases are supposed to be reversible and are encrypted.
 * @see de.mlessmann.certassist.service.PassphraseService
 */
@Entity
@Getter
@Table(uniqueConstraints = { @UniqueConstraint(columnNames = { "identifier" }) })
public class Passphrase {

    @Id
    @GeneratedValue(strategy = GenerationType.UUID)
    @Setter(AccessLevel.NONE)
    private String id;

    @Setter
    @Column(nullable = false)
    private String identifier;

    @Setter
    @Column(nullable = false)
    private String encPassphrase;

    @Setter
    @Column(nullable = false)
    private String salt;

    @CreationTimestamp
    @Column(nullable = false, updatable = false)
    private ZonedDateTime created;

    @UpdateTimestamp
    @Column(nullable = false)
    private ZonedDateTime updated;

    @Setter
    @Transient
    private String passphrase;
}
